package cn.com.infosec.mobile.android.util;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Process;
import android.os.Build.VERSION;
import android.security.keystore.KeyGenParameterSpec;
import android.support.annotation.RequiresApi;
import android.text.TextUtils;
import android.util.Base64;
import cn.com.infosec.mobile.android.result.Result;
import java.security.KeyPairGenerator;
import java.security.KeyStore;
import java.security.Signature;

public class KeyStoreUtil {
   private Context context;
   private byte[] deviceSignBytes;

   private KeyStoreUtil() {
      this.deviceSignBytes = new byte[0];
   }

   public static KeyStoreUtil getInstance(Context context) {
      KeyStoreUtil.KeyStoreTool.instance.context = context;
      return KeyStoreUtil.KeyStoreTool.instance;
   }

   @RequiresApi(23)
   public static void getKeyPair(String alias) {
      KeyPairGenerator var10000 = KeyPairGenerator.getInstance("EC", "AndroidKeyStore");
      var10000.initialize((new KeyGenParameterSpec.Builder(alias, 12)).setDigests(new String[]{"SHA-256", "SHA-512"}).build());
      var10000.generateKeyPair();
   }

   public static byte[] sign(String alias, byte[] data) {
      KeyStore var10000 = KeyStore.getInstance("AndroidKeyStore");
      var10000.load((KeyStore.LoadStoreParameter)null);
      KeyStore.Entry alias1;
      if (!((alias1 = var10000.getEntry(alias, (KeyStore.ProtectionParameter)null)) instanceof KeyStore.PrivateKeyEntry)) {
         return null;
      } else {
         Signature var3 = Signature.getInstance("SHA256withECDSA");
         var3.initSign(((KeyStore.PrivateKeyEntry)alias1).getPrivateKey());
         var3.update(data);
         return var3.sign();
      }
   }

   public static boolean verify(String alias, byte[] data, byte[] signature) {
      KeyStore var10000 = KeyStore.getInstance("AndroidKeyStore");
      var10000.load((KeyStore.LoadStoreParameter)null);
      KeyStore.Entry alias1;
      if (!((alias1 = var10000.getEntry(alias, (KeyStore.ProtectionParameter)null)) instanceof KeyStore.PrivateKeyEntry)) {
         return false;
      } else {
         Signature var3;
         Signature var5 = var3 = Signature.getInstance("SHA256withECDSA");
         var3.initVerify(((KeyStore.PrivateKeyEntry)alias1).getCertificate());
         var3.update(data);
         return var5.verify(signature);
      }
   }

   private boolean checkSign(String userName) {
      if (VERSION.SDK_INT >= 23) {
         Exception var10000;
         label26: {
            boolean var10001;
            byte[] var10002;
            String var5;
            KeyStoreUtil var6;
            try {
               var5 = userName;
               var6 = this;
               this.deviceSignBytes = Base64.decode(this.getDeviceInfoSign(userName), 2);
               var10002 = this.getDeviceInfo().getBytes();
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
               break label26;
            }

            byte[] var4 = var10002;

            try {
               return verify(var5, var4, var6.deviceSignBytes);
            } catch (Exception var2) {
               var10000 = var2;
               var10001 = false;
            }
         }

         var10000.printStackTrace();
         return false;
      } else {
         return true;
      }
   }

   private SharedPreferences getUserSP(String userName) {
      return this.context.getSharedPreferences(userName, 0);
   }

   private String getDeviceInfoSign(String userName) {
      return this.context.getSharedPreferences(userName, 0).getString("DEVICE_INFO_SIGN", (String)null);
   }

   private String getDeviceInfo() {
      return Build.MODEL + "/" + Build.MANUFACTURER + "/" + Build.BRAND + "/" + Build.HARDWARE + "/" + Process.myUid();
   }

   // $FF: synthetic method
   KeyStoreUtil(Object x0) {
      this();
   }

   public Result initCheck(String userName) {
      if (VERSION.SDK_INT < 23) {
         return new Result("000000");
      } else {
         if (TextUtils.isEmpty(this.getDeviceInfoSign(userName))) {
            KeyStoreUtil var10000 = this;
            String var10001 = userName;
            String var10002 = userName;
            String var10003 = userName;
            String var2 = this.getDeviceInfo();

            Exception var7;
            label56: {
               boolean var8;
               byte[] var10;
               try {
                  getKeyPair(var10003);
                  var10 = sign(var10002, var2.getBytes());
               } catch (Exception var6) {
                  var7 = var6;
                  var8 = false;
                  break label56;
               }

               byte[] var11 = var10;

               try {
                  this.deviceSignBytes = var11;
                  var10002 = Base64.encodeToString(var10, 2);
               } catch (Exception var5) {
                  var7 = var5;
                  var8 = false;
                  break label56;
               }

               var2 = var10002;

               SharedPreferences.Editor var9;
               try {
                  var9 = var10000.getUserSP(var10001).edit();
                  var9.putString("DEVICE_INFO_SIGN", var2);
               } catch (Exception var4) {
                  var7 = var4;
                  var8 = false;
                  break label56;
               }

               try {
                  var9.commit();
                  return !this.checkSign(userName) ? new Result("IE1065", "initCheck方法，checkSign非法拷贝异常") : new Result("000000");
               } catch (Exception var3) {
                  var7 = var3;
                  var8 = false;
               }
            }

            var7.printStackTrace();
         }

         return !this.checkSign(userName) ? new Result("IE1065", "initCheck方法，checkSign非法拷贝异常") : new Result("000000");
      }
   }

   private static class KeyStoreTool {
      private static final KeyStoreUtil instance = new KeyStoreUtil();
   }
}
